<?php
/**
 * @package SiteTree
 * @author Luigi Cavalieri
 * @license http://opensource.org/licenses/GPL-2.0 GPLv2.0 Public license
 * -------------------------------------------------------------------------- */

/**
 *
 *
 * @since 1.4
 */
abstract class SiteTreeFieldView {
	/**
	 *
	 *
	 * @since 1.4
	 */
	protected $field;
	
	/**
	 *
	 *
	 * @since 1.4
	 */
	protected $id;
	
	/**
	 *
	 *
	 * @since 1.4
	 */
	protected $name;
	
	/**
	 *
	 *
	 * @since 1.4
	 */
	protected $value;
	
	/**
	 *
	 *
	 * @since 1.4
	 */
	public function __construct( $field, $sectionId = '' ) {
		$this->field = $field;
		$this->id = str_replace('_', '-', $this->field->id);
		
		$this->name  = 'sitetree';
		$this->name .= $sectionId ? ('[' . $sectionId . ']') : '';
		$this->name .= '[' . $this->field->id . ']';
	}
	
	/**
	 *
	 *
	 * @since 1.4
	 */
	public function setValue( $value ) {
		$this->value = $value;
	}
	
	/**
	 *
	 *
	 * @since 1.4
	 */
	abstract public function render();
	
	/**
	 *
	 *
	 * @since 1.4
	 */
	protected function render_tooltip() {
		if ( $this->field->tooltip ) {
			echo "\n" . '<span class="description">';
			echo wp_kses( $this->field->tooltip, array( 'code' => true, 'a' => array( 'href' => true ) ) );
			echo '</span>';
		}
	}
}


/**
 *
 *
 * @since 1.4
 */
class SiteTreeCheckbox extends SiteTreeFieldView {
	/**
	 *
	 *
	 * @since 1.4
	 */
	public function render() {
		echo '<input type="checkbox" id="' . $this->id . '" name="' . $this->name 
		   . '" value="1"' . checked( true, $this->value, false ) . " />\n"
		   . '<label for="' . $this->name . '">' . $this->field->tooltip . '</label>';
	}
}


/**
 *
 *
 * @since 1.4
 */
class SiteTreeDropdown extends SiteTreeFieldView {
	/**
	 *
	 *
	 * @since 1.4
	 */
	public function render() {
		echo '<select id="' . $this->id . '" name="' . $this->name . '">';
		
		foreach ( $this->field->config as $value => $label )
			echo '<option value="' . $value . '"' . selected( $value, $this->value, false ) . '>' . $label . '</option>';
		
		echo '</select>';
		
		$this->render_tooltip();
	}
}

/**
 *
 *
 * @since 1.4
 */
class SiteTreeTextField extends SiteTreeFieldView {
	/**
	 *
	 *
	 * @since 1.4
	 */
	public function render() {
		$class = $this->field->config ? $this->field->config : 'regular-text';
		
		echo '<input type="text" name="' . $this->name . '" value="' . $this->value . '" class="' . $class . '" />';
		   
		$this->render_tooltip();
	}
}

/**
 *
 *
 * @since 1.4
 */
class SiteTreeTextarea extends SiteTreeFieldView {
	/**
	 *
	 *
	 * @since 1.4
	 */
	public function render() {
		echo '<textarea name="' . $this->name . '" class="code" />' . $this->value . '</textarea><br />';
		   
		$this->render_tooltip();
	}
}

/**
 *
 *
 * @since 1.4
 */
class SiteTreeNumberField extends SiteTreeFieldView {
	/**
	 *
	 *
	 * @since 1.4
	 */
	public function render() {
		echo '<input type="number" name="' . $this->name . '" value="' . $this->value
		   . '" min="' . $this->field->config['min_value'] . '" max="' . $this->field->config['max_value'] . '" class="small-text" />';
		   
		$this->render_tooltip();
	}
}
?>